@@ -112,8 +112,7 @@ class XMLToHTML(XMLToX):
     def start_code(self):
         self.write("<PRE>")
     def end_file(self):
-        self.write("<HR>\n"+\
-                   self.footer+\
+        self.write(self.footer+\
                    "\n</BODY></HTML>")
     def end_chap(self):
         self.write("\n")
