@@ -1,7 +1,7 @@
 
 -- line pattern: any complete line of square is removed ----------------------
 
-function delete_line(y_line)
+function line_delete(y_line)
     local x
     local y
     local width
@@ -15,7 +15,7 @@ function delete_line(y_line)
     end
 end
 
-function match_line(match_count)
+function line_match_pattern(match_count)
     local x
     local y
     local width
@@ -41,16 +41,16 @@ function match_line(match_count)
             x=x+1
         end
         if holes==0 then 
-            delete_line(y)
+            line_delete(y)
             lines=lines+1
         end
         y=y+1
     end    
 
     if lines>0 then
-        u61_add_score((match_count+1)*1000)    
+        u61_add_score((match_count+1)*10000)    
         if (match_count>=3) then
-            u61_add_antedote()
+            u61_add_antidote()
         end
     end
 
