@@ -1,7 +1,7 @@
 
 -- splits the block so that every square is as low as possible ---------------
 
-function highest_square(x)
+function split_get_highest_square(x)
     local y
     local height
     local y_min
@@ -36,7 +36,7 @@ function split_block()
     size=u61_get_nb_items()
     x=0
     while x<width do
-        y_min=highest_square(x)
+        y_min=split_get_highest_square(x)
         y=y_min-1
         while y>=0 do
             i=0
