@@ -61,4 +61,44 @@ function utils_clear_map()
         end
         y=y+1
     end
+end
+
+function utils_switch_lines(y1,y2)
+    local x
+    local color
+
+    x=u61_get_width()-1
+    while x>=0 do
+        color=u61_get_square_color(x,y1)
+        u61_set_square_color(x,y1,u61_get_square_color(x,y2))
+        u61_set_square_color(x,y2,color)
+        x=x-1
+    end
+end
+
+function utils_get_highest_square_y()
+    local x
+    local y
+    local width
+    local height
+    local min_y	
+
+    width=u61_get_width()
+    height=u61_get_height()
+    min_y=height 
+    y=0
+    while y<height do
+        x=0
+        while x<width do
+            if u61_get_square_color(x,y)>=0 then
+                min_y=y
+                x=width
+                y=height
+            end
+            x=x+1
+        end
+        y=y+1
+    end 
+
+    return min_y   
 end
\ No newline at end of file
